package de.intevation.gnv.artifactdatabase.client;

import de.intevation.gnv.artifactdatabase.objects.ArtifactDescription;
import de.intevation.gnv.artifactdatabase.objects.ArtifactObject;
import de.intevation.gnv.artifactdatabase.objects.DefaultInputParameter;
import de.intevation.gnv.artifactdatabase.objects.InputParameter;

import de.intevation.gnv.util.XSLTransformer;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Locale;

import junit.framework.TestCase;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class ArtifactDatabaseClientTestCase extends TestCase {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = null;

    static {
        BasicConfigurator.configure();
        log = Logger.getLogger(DefaultArtifactDatabaseClient.class);
    }

    /**
     * Constructor
     *
     * @param namemessage
     */
    public ArtifactDatabaseClientTestCase(String name) {
        super(name);
    }

    /**
     * @see junit.framework.TestCase#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
    }

    public void testArtifactDatabaseClient() {

        try {
            ArtifactDatabaseClient artifactDatabaseClient = ArtifactDatabaseClientFactory
                    .getInstance().getArtifactDatabaseClient(Locale.GERMAN);
            Collection<ArtifactObject> factories = artifactDatabaseClient
                    .getArtifactFactories();
            if (factories != null && !factories.isEmpty()) {
                Iterator<ArtifactObject> it = factories.iterator();
                while (it.hasNext()) {
                    ArtifactObject aof = it.next();
                    ArtifactObject artifact = artifactDatabaseClient
                            .createNewArtifact(aof);
                    ArtifactDescription ad = artifactDatabaseClient
                            .getCurrentStepDescription(aof, artifact,true);
                    log.debug("Artifact aktualisert.");
                    XSLTransformer transformer = new XSLTransformer();
                    String transformedUI = transformer
                            .transform(
                                    ad.getCurrentUI(),
                                    "UTF-8",
                                    ("src/main/webapp/WEB-INF/config/templates/describe-ui.xsl"));
                    log.debug(transformedUI);

                    Collection<InputParameter> inputParameter = new ArrayList<InputParameter>(
                            1);
                    inputParameter.add(new DefaultInputParameter("product",
                            new String[] { "timeSeries" }));
                    ad = artifactDatabaseClient.doNextStep(aof, artifact,
                            "timeSeries", inputParameter);

                    transformedUI = transformer
                            .transform(
                                    ad.getCurrentUI(),
                                    "UTF-8",
                                    ("src/main/webapp/WEB-INF/config/templates/describe-ui.xsl"));
                    log.debug(transformedUI);
                }
            }

        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
